"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.bufferToJson = void 0;
const defined_1 = require("./defined");
const Buffers_1 = require("./Buffers");
/**
 * Converts a buffer containing a utf-8 encoded JSON string (without BOM) to a JSON object.
 * If the buffer is undefined or empty, then an empty object will be returned.
 *
 * @param buffer - The buffer.
 * @returns A JSON object.
 */
function bufferToJson(buffer) {
    if (!buffer) {
        return {};
    }
    if (buffer.length === 0) {
        return {};
    }
    const bom = Buffers_1.Buffers.getUnicodeBOMDescription(buffer);
    if ((0, defined_1.defined)(bom)) {
        const message = `Unexpected BOM in JSON buffer: ${bom}`;
        throw new Error(message);
    }
    const s = buffer.toString();
    return JSON.parse(s);
}
exports.bufferToJson = bufferToJson;
