"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TilesetPackageBuilderFs = void 0;
const defined_1 = require("./base/defined");
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const TilesetPackageError_1 = require("./TilesetPackageError");
/**
 * Implementation of a TilesetPackageBuilder that writes into
 * a directory of a file system
 */
class TilesetPackageBuilderFs {
    /**
     * Default constructor
     */
    constructor() {
        this.fullOutputName = undefined;
        this.overwrite = false;
    }
    begin(fullOutputName, overwrite) {
        if ((0, defined_1.defined)(this.fullOutputName)) {
            throw new TilesetPackageError_1.TilesetPackageError("Package already opened");
        }
        this.fullOutputName = fullOutputName;
        this.overwrite = overwrite;
        if (!fs_1.default.existsSync(fullOutputName)) {
            fs_1.default.mkdirSync(fullOutputName, { recursive: true });
        }
    }
    addEntry(key, content) {
        if (!(0, defined_1.defined)(this.fullOutputName)) {
            throw new TilesetPackageError_1.TilesetPackageError("Package is not opened. Call 'begin' first.");
        }
        const fullOutputFileName = path_1.default.join(this.fullOutputName, key);
        if (fs_1.default.existsSync(fullOutputFileName)) {
            if (!this.overwrite) {
                throw new TilesetPackageError_1.TilesetPackageError("File already exists: " + fullOutputFileName);
            }
        }
        // TODO Need to unlink if file exists?
        fs_1.default.mkdirSync(path_1.default.dirname(fullOutputFileName), { recursive: true });
        fs_1.default.writeFileSync(fullOutputFileName, content);
    }
    async end() {
        if (!(0, defined_1.defined)(this.fullOutputName)) {
            throw new TilesetPackageError_1.TilesetPackageError("Package is not opened. Call 'begin' first.");
        }
        this.fullOutputName = undefined;
        this.overwrite = false;
    }
}
exports.TilesetPackageBuilderFs = TilesetPackageBuilderFs;
