"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TilesetPackageFs = void 0;
const defined_1 = require("./base/defined");
const Iterables_1 = require("./base/Iterables");
const relativizePath_1 = require("./base/relativizePath");
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const TilesetPackageError_1 = require("./TilesetPackageError");
/**
 * Implementation of a TilesetPackage based on a directory
 * in a file system
 */
class TilesetPackageFs {
    /**
     * Default constructor
     */
    constructor() {
        this.fullInputName = undefined;
    }
    open(fullInputName) {
        if ((0, defined_1.defined)(this.fullInputName)) {
            throw new TilesetPackageError_1.TilesetPackageError("Package already opened");
        }
        this.fullInputName = fullInputName;
    }
    getKeys() {
        if (!(0, defined_1.defined)(this.fullInputName)) {
            throw new TilesetPackageError_1.TilesetPackageError("Package is not opened. Call 'open' first.");
        }
        const files = Iterables_1.Iterables.overFiles(this.fullInputName, true);
        return Iterables_1.Iterables.map(files, (file) => (0, relativizePath_1.relativizePath)(this.fullInputName, file));
    }
    getEntry(key) {
        if (!(0, defined_1.defined)(this.fullInputName)) {
            throw new TilesetPackageError_1.TilesetPackageError("Package is not opened. Call 'open' first.");
        }
        const fullFileName = path_1.default.join(this.fullInputName, key);
        if (!fs_1.default.existsSync(fullFileName)) {
            return undefined;
        }
        const data = fs_1.default.readFileSync(fullFileName);
        return data;
    }
    close() {
        if (!(0, defined_1.defined)(this.fullInputName)) {
            throw new TilesetPackageError_1.TilesetPackageError("Package is not opened. Call 'open' first.");
        }
        this.fullInputName = undefined;
    }
}
exports.TilesetPackageFs = TilesetPackageFs;
